@@ -9,6 +9,8 @@ __all__ = (
     'AppWindow',
     'CaptchaDialog',
     'ComboBox',
+    'ConversationsContextMenu',
+    'ConversationTabs',
     'ConversationView',
     'ExceptionLogger',
     'ExceptionReporter',
@@ -32,9 +34,11 @@ from .aliases import tr
 from .app import GetterApp
 from .app import Theme
 from .menus import AccountContextMenu
+from .menus import ConversationsContextMenu
 from .menus import HelpContextMenu
 from .menus import ToolsContextMenu
 from .widgets import ComboBox
+from .widgets import ConversationTabs
 from .widgets import ConversationView
 from .widgets import ExceptionLogger
 from .widgets import ExternalTextBrowser
