@@ -5,6 +5,7 @@
 
 __all__ = (
     'ComboBox',
+    'ConversationTabs',
     'ConversationView',
     'ExceptionLogger',
     'ExternalTextBrowser',
@@ -16,6 +17,7 @@ __all__ = (
 from .combo_box import ComboBox
 from .combo_box import HistoryComboBox
 from .combo_box import TranslatableComboBox
+from .conversation_tabs import ConversationTabs
 from .conversation_view import ConversationView
 from .exception_logger import ExceptionLogger
 from .external_text_browser import ExternalTextBrowser
