@@ -22,6 +22,9 @@ import datetime as dt
 from bs4 import BeautifulSoup
 from PySide6.QtCore import *
 from PySide6.QtGui import *
+from selenium.webdriver import DesiredCapabilities
+from selenium.webdriver.common.proxy import Proxy
+from selenium.webdriver.common.proxy import ProxyType
 from tls_client import Session as TlsSession
 from undetected_chromedriver import Chrome
 from undetected_chromedriver import ChromeOptions
@@ -321,7 +324,10 @@ class Authenticator(QObject):
             self.authenticationFailed.emit(self.username, e)
 
     def cloudflare_clearance(self) -> None:
-        """Set cf_clearance cookie and associated user agent."""
+        """Set cf_clearance cookie and associated user agent.
+
+        :raises RuntimeError: If the Chrome webdriver failed to start.
+        """
         clearance_obtained: bool = False
 
         def set_cookies(message: dict[str, Any]) -> None:
@@ -332,7 +338,7 @@ class Authenticator(QObject):
 
             cookie_values: dict[str, str] = {}
 
-            for cookie_name in ('__cf_bm', 'cf_clearance',):
+            for cookie_name in ('__cf_bm', '_cfuvid', 'cf_clearance'):
                 # Use regex to get the cookies
                 pattern = re.compile(f'{cookie_name}=.*?;')
                 if match := pattern.match(set_cookie_header):
@@ -348,6 +354,8 @@ class Authenticator(QObject):
 
                         if cookie_name == '__cf_bm':
                             self.session_data.cf_bm = value
+                        elif cookie_name == '_cfuvid':
+                            self.session_data.cf_unique_visitor_id = value
                         elif cookie_name == 'cf_clearance':
                             self.session_data.cf_clearance = value
                             self.session_data.cf_expires = dt.datetime.now() + dt.timedelta(hours=1)
@@ -362,6 +370,22 @@ class Authenticator(QObject):
                 self.updateUserAgent.emit(ua)
 
         options = ChromeOptions()
+        if self.session.proxies:
+            proxy = Proxy()
+            proxy.proxy_type = ProxyType.MANUAL
+            if http := self.session.proxies.get('http'):
+                if (match := CG_PROXY_PATTERN.match(http)) is not None:
+                    config: dict[str, str] = match.groupdict()
+                    proxy.http_proxy = f'{config["host"]}:{config["port"]}'
+            if socks := self.session.proxies.get('socks5'):
+                if (match := CG_PROXY_PATTERN.match(socks)) is not None:
+                    config: dict[str, str] = match.groupdict()
+                    proxy.socks_proxy = f'{config["host"]}:{config["port"]}'
+                    proxy.socks_username = config['username']
+                    proxy.socks_password = config['password']
+            proxy.add_to_capabilities(DesiredCapabilities.CHROME)
+            options.proxy = proxy
+
         for argument in (
                 '--disable-extensions', '--disable-application-cache',
                 '--disable-gpu', '--no-sandbox',
@@ -370,7 +394,11 @@ class Authenticator(QObject):
         ):
             options.add_argument(argument)
 
-        driver = Chrome(enable_cdp_events=True, options=options)
+        try:
+            driver = Chrome(enable_cdp_events=True, options=options)
+        except Exception as e:
+            raise RuntimeError('Couldn\'t start Chrome webdriver. Make sure you have Google Chrome installed.') from e
+
         driver.add_cdp_listener('Network.responseReceivedExtraInfo', set_cookies)
         if not self.session_data.user_agent:
             driver.add_cdp_listener('Network.requestWillBeSentExtraInfo', set_user_agent)
